package org.cds.vizmine;

public class Galactic {

	private Ra ra;
	private Dec dec;
	
	public Galactic(double l, double b) {
		// Longitude transform --- 0° -> 360°
		ra = new Ra(l);
		
		// Latitude transform
		dec = new Dec(b);
	}
	
	public Ra getRa() {
		return ra;
	}
	
	public Dec getDec() {
		return dec;
	}
	
	public String toString() {
		return ra + "\n" + dec;
	}
	
	public class Ra {
		
		private int h, m, s;
		
		public Ra(double l) {
			double temp;
			
			temp = l / 15;
			h = (int) temp;
			
			temp = (temp - h) * 60;
			m = (int) temp;
			
			temp = (temp - m) * 60;
			s = (int) temp;
		}
		
		public int getH() {
			return h;
		}
		
		public int getM() {
			return m;
		}
		
		public int getS() {
			return s;
		}
		
		public String toString() {
			StringBuffer sb = new StringBuffer("ra:\t");
			if (h < 10)
				sb.append("0");
			sb.append(h + "h");
			if (m < 10)
				sb.append("0");
			sb.append(m + "m");
			if (s < 10)
				sb.append("0");
			sb.append(s + "s");
			
			return sb.toString();
		}
	} // End of Ra subclass
	
	public class Dec {
		
		private int h, m, s;
		private boolean neg;
		
		public Dec(double b) {
			double temp;
			
			if (b >= 0) { // 0° -> 90°
				neg = false;
			} else { //  -90° -> 0°
				neg = true;
				b = -b;
			}
			
			h = (int) b;
			
			temp = (b - h) * 60;
			m = (int) temp;
			
			temp = (temp - m) * 60;
			s = (int) temp;
		}
		
		public int getH() {
			return h;
		}
		
		public int getM() {
			return m;
		}
		
		public int getS() {
			return s;
		}
		
		public boolean isNeg() {
			return neg;
		}
		
		public String toString() {
			StringBuffer sb = new StringBuffer("dec:\t");
			if (neg)
				sb.append("-");
			else
				sb.append("+");
			
			if (h < 10)
				sb.append("0");
			sb.append(h + "°");
			if (m < 10)
				sb.append("0");
			sb.append(m + "\"");
			if (s < 10)
				sb.append("0");
			sb.append(s + "\'");
			return sb.toString();
		}
	} // End of Dec subclass

}
